%%
%% This is file `quadrature.cls'
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{quadrature}
              [2010/11/10 v2.0 Class for Quadrature magazine]
\LoadClass[11pt, twoside, twocolumn]{article}
\newif\ifQDT@experimental\QDT@experimentalfalse
\DeclareOption{exp}{\QDT@experimentaltrue}
\newif\ifQDT@imprimeur\QDT@imprimeurfalse
\DeclareOption{imprimeur}{\QDT@imprimeurtrue}
% option de codage d'entrée
\DeclareOption{ascii}{\def\QDT@codage{ascii}}
\DeclareOption{latin1}{\def\QDT@codage{latin1}}
\DeclareOption{latin9}{\def\QDT@codage{latin9}}
\DeclareOption{ansinew}{\def\QDT@codage{ansinew}}
\DeclareOption{applemac}{\def\QDT@codage{applemac}}
\DeclareOption{utf8}{\def\QDT@codage{utf8}}
% option pour la couleur du texte sur fond coloré
\newcommand\TextColorFramed[1]{%
  \colorlet{Qdt@blackorwhite}{#1}%
}
\newcommand\Qdt@TextColorFramed[1]{%
  \def\Qdt@SetTextColorFramed{\colorlet{Qdt@blackorwhite}{#1}}%
}
\DeclareOption{black}{\Qdt@TextColorFramed{black}}
\DeclareOption{white}{\Qdt@TextColorFramed{white}}
% Blanc par défaut
\Qdt@TextColorFramed{white}
% utf8 par défaut
\def\QDT@codage{utf8}
%\ExecuteOptions{}
\ProcessOptions
\RequirePackage[T1]{fontenc}
\expandafter\RequirePackage\expandafter[\QDT@codage]{inputenc}
\RequirePackage{calc, ifmtarg}
\RequirePackage{mathptmx}
\RequirePackage[scaled]{helvet}
\renewcommand\ttdefault{lmtt}
\RequirePackage{textcomp}
\renewcommand\textcompsubstdefault{lmr} % au lieu de cmr (c'est mieux)
\RequirePackage[official]{eurosym}
\RequirePackage[a4paper, left=18.5mm, right=18.5mm,
                nohead, top=1cm, bottom=2.9cm, footskip=1.2cm]
               {geometry}
\AtBeginDocument{\setlength{\columnsep}{7mm}}
\ifQDT@imprimeur
\RequirePackage[cam, width=24truecm, height=33truecm,
                center, font=texttt]{crop}
\fi
\ifQDT@experimental
  \RequirePackage{cuted}
\else
  \RequirePackage{dblfloatfix}
\fi
\RequirePackage{fancyhdr, afterpage}
\RequirePackage{xcolor, graphicx, tikz}
\RequirePackage{url, framed, wrapfig, enumerate}
\urlstyle{same}
\RequirePackage{amsmath, amssymb, amsthm, thmtools}
\RequirePackage{yhmath} % Très larges symboles
%%% La définition de l'environnement amatrix dans yhmath est fautive
\renewenvironment{amatrix}
  {\left\langle\begin{matrix}}
  {\end{matrix}\right\rangle}
%%%
\RequirePackage{stmaryrd} % symboles exotiques
\RequirePackage{xkeyval}
\RequirePackage[french]{babel}
\def\QDT@string@utf{utf8}
\ifx\frenchbsetup\relax\else
  \ifx\QDT@codage\QDT@string@utf
    \frenchbsetup{og=«,fg=»,ThinSpaceInFrenchNumbers=true}
  \else
    \frenchbsetup{ThinSpaceInFrenchNumbers=true}
  \fi
\fi
\RequirePackage[autolanguage]{numprint}
\RequirePackage{microtype}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page générale %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\columnsep}{4mm}

%%%%%%%%%%%%%%%%
%%% Couleurs %%%
%%%%%%%%%%%%%%%%

% pdf en cyan ou en couleur cmyk ?

\newif\ifQdt@cyan
\Qdt@cyantrue

\ifQdt@cyan
  % Pour tous les numéros
  \definecolor{Qdt@n0}{cmyk}{0,0,0,0.25}
  \definecolor{Qdt@n1}{cmyk}{0,0,0,0.5}
  \definecolor{Qdt@c0}{cmyk}{0.5,0,0,1} 
  \definecolor{Qdt@c1}{cmyk}{1,0,0,0}
  \definecolor{Qdt@c2}{cmyk}{1,0,0,0} % couleur d'accompagnement
                                      % principale = 100 % cyan et c'est tout
  \definecolor{Qdt@c3}{cmyk}{0.7,0,0,0}
  \definecolor{Qdt@c4}{cmyk}{0.5,0,0,0.5}
  \definecolor{Qdt@c5}{cmyk}{0.2,0,0,0}
\else
  % Propre à chaque numéro
  \definecolor{Qdt@n0}{cmyk}{0,0,0,0.25}
  \definecolor{Qdt@n1}{cmyk}{0,0,0,0.5}
  \definecolor{Qdt@c0}{cmyk}{0,0.37,0.37,0.1}
  \definecolor{Qdt@c1}{cmyk}{0,0.73,0.73,0.49}
  \definecolor{Qdt@c2}{cmyk}{0,0.73,0.73,0.49}
  \definecolor{Qdt@c3}{cmyk}{0,0.73,0.73,0.49}
  \definecolor{Qdt@c4}{cmyk}{0,0.37,0.37,0.75}
\fi

% Gestion des couleurs de façon sémantique
\newcommand*\Qdt@assigncolor[2]{%
  \colorlet{#1}{#2}%
  \@namedef{#1}{\color{#1}}
}
% Texte sur fonc coloré (via les options de classe)
\Qdt@SetTextColorFramed
% Première page
\Qdt@assigncolor{Qdt@firstfootrulecolor}{Qdt@c4} % rectangle de pied
                                                 % de page
\Qdt@assigncolor{Qdt@titletoccolor}{Qdt@c1} % Mot « Sommaire »
\Qdt@assigncolor{Qdt@titletocarticlecolor}{black}
\Qdt@assigncolor{Qdt@titletocauthorcolor}{black}
\Qdt@assigncolor{Qdt@titlereviewcolor}{black} % « Quadrature » en haut
                                              % à gauche sous le logo
\Qdt@assigncolor{Qdt@titledistributioncolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@authordistributioncolor}{black}
\Qdt@assigncolor{Qdt@frameeditorialcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@textframeeditorialcolor}{Qdt@blackorwhite}
% Toutes les pages
\Qdt@assigncolor{Qdt@DOIcolor}{black}
\Qdt@assigncolor{Qdt@rulecolor}{Qdt@c3}
\Qdt@assigncolor{Qdt@footrulecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@textfootrulecolor}{Qdt@blackorwhite}
\Qdt@assigncolor{Qdt@sectioncolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@subsectioncolor}{Qdt@c3}
\Qdt@assigncolor{Qdt@subsubsectioncolor}{black}
\Qdt@assigncolor{Qdt@paragraphcolor}{black}
\Qdt@assigncolor{Qdt@subparagraphcolor}{black}
\Qdt@assigncolor{Qdt@titletheoremcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@qedcolor}{Qdt@c3}
\Qdt@assigncolor{Qdt@captioncolor}{Qdt@c2}
% Tout le monde
\Qdt@assigncolor{Qdt@titleabstractcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@abstractcolor}{black}
\Qdt@assigncolor{Qdt@authorcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@framecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@textframecolor}{Qdt@blackorwhite}
% Articles
\Qdt@assigncolor{Qdt@subarticlecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@subarticlebracketcolor}{Qdt@n1}
\Qdt@assigncolor{Qdt@titlearticlecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@subtitlearticlecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@epigraphecolor}{black}
% Rubriques
\Qdt@assigncolor{Qdt@titlerubriccolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@TEQsubtitlecolor}{black}
\Qdt@assigncolor{Qdt@TEQsectioncolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@TEQframecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@TEQtextframecolor}{Qdt@blackorwhite}
\Qdt@assigncolor{Qdt@TEQellipsecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@TEQtitleinterrogationcolor}{Qdt@c5}
\Qdt@assigncolor{Qdt@TEQellipseinterrogationcolor}{white}
\Qdt@assigncolor{Qdt@NDLtitlebookcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@NDLsubtitlebookcolor}{Qdt@c1}
\Qdt@assigncolor{Qdt@CDPtitlestatementcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@CDPoldreviewcolor}{Qdt@c3}
\Qdt@assigncolor{Qdt@CDPoldstatementcolor}{black}
\Qdt@assigncolor{Qdt@CDPnewstatementcolor}{Qdt@c1}
\Qdt@assigncolor{Qdt@CDPauthornewstatementcolor}{Qdt@c3}
\Qdt@assigncolor{Qdt@ECEtitlecolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@ECEtitleshadecolor}{Qdt@c0}
\Qdt@assigncolor{Qdt@ECEauthorcolor}{Qdt@c2}
\Qdt@assigncolor{Qdt@ECEauthorshadecolor}{Qdt@c4}
\Qdt@assigncolor{Qdt@ECEsubtitlecolor}{black}
\Qdt@assigncolor{Qdt@ECEsubtitleshadecolor}{Qdt@n0}
\Qdt@assigncolor{Qdt@ECEabstractcolor}{black}
%
% Cadre en cyan pur et texte blanc
%
\newenvironment{QDTshaded}{%
  \def\FrameCommand{%
    \FrameSep=3mm
    \FrameRule=0mm
    \fboxsep=\FrameSep
    \fboxrule=\FrameRule
    \colorbox{shadecolor}%
  }%
  \MakeFramed{%
    \advance\hsize-6mm
    \FrameRestore
  }%
}%
{\endMakeFramed}

\newcommand\encadre[1]{%
  \begingroup
    \colorlet{shadecolor}{Qdt@framecolor}%
    \color{Qdt@textframecolor}%
    \begin{QDTshaded}
      \strut
      #1%
      \strut
      \par
    \end{QDTshaded}%
  \endgroup
}
%
%%%%%%%%%%%%%%
%%% Fontes %%%
%%%%%%%%%%%%%%

% Gestion des fontes de façon sémantique
% Toutes les pages
\newcommand\Qdt@DOIfont{\rmfamily\footnotesize}
% La taille de \Qdt@footfont ne doit pas dépendre de la taille de
% fonte courante. \footnotesier en 11pt = ce qui est indiqué
\newcommand\Qdt@footfont{\sffamily\bfseries
                         \fontsize{9pt}{11pt}\selectfont}
\newcommand\Qdt@sectionfont{\sffamily\bfseries\Large}
\newcommand\Qdt@subsectionfont{\sffamily\bfseries\large}
\newcommand\Qdt@subsubsectionfont{\sffamily\bfseries}
\newcommand\Qdt@paragraphfont{\sffamily\bfseries}
\newcommand\Qdt@subparagraphfont{\sffamily\bfseries}
\newcommand\Qdt@titletheoremfont{\sffamily\bfseries}
\newcommand\Qdt@captionfont{\sffamily\footnotesize}
% Distribution-Sommaire-Éditorial
\newcommand\Qdt@titletocfont{\sffamily
                             \fontsize{1.8cm}{1.8cm}\selectfont}
\newcommand\Qdt@titletocarticlefont{\sffamily\bfseries\small}
\newcommand\Qdt@titletocauthorfont{\sffamily\itshape\small}
\newcommand\Qdt@titlereviewfont{\sffamily\bfseries\Large}
\newcommand\Qdt@titledistributionfont{\sffamily\bfseries\small}
\newcommand\Qdt@authordistributionfont{\sffamily\small}
\newcommand\Qdt@quoteeditorialfont{\sffamily\bfseries
                                   \fontsize{3cm}{3cm}\selectfont}
\newcommand\Qdt@titleeditorialfont{\sffamily\huge}
\newcommand\Qdt@authoreditorialfont{\sffamily\itshape}
\newcommand\Qdt@editorialfont{\sffamily\small}
\newcommand\Qdt@titlecontactfont{\bfseries\small}
\newcommand\Qdt@contactfont{\small}
% Articles
\newcommand\Qdt@subarticlefont{\sffamily\bfseries\Large}
\newcommand\Qdt@subarticlebracketfont{\sffamily\LARGE}
\newcommand\Qdt@titlearticlefont{\sffamily\bfseries\Huge}
\newcommand\Qdt@subtitlearticlefont{\sffamily\bfseries\Large}
\newcommand\Qdt@titleabstractfont{\sffamily\bfseries\large}
\newcommand\Qdt@abstractfont{\normalfont\normalcolor}
\newcommand\Qdt@authorfont{\sffamily\large\normalcolor}
\newcommand\Qdt@epigraphefont{\normalfont\normalcolor}
% Rubriques
\newcommand\Qdt@titlerubricfont{%
  \sffamily\fontsize{2.5cm}{2.5cm}\selectfont}
\newcommand\Qdt@smalltitlerubricfont{%
  \sffamily\fontsize{1.5cm}{1.5cm}\selectfont}
\newcommand\Qdt@TEQsubtitlefont{\sffamily\bfseries\LARGE}
\newcommand\Qdt@TEQsectionfont{\sffamily\bfseries\small}
\newcommand\Qdt@TEQtitleinterrogationfont{\fontsize{18cm}{18cm}\selectfont}
\newcommand\Qdt@TEQellipseinterrogationfont{\fontsize{2.5cm}{2.5cm}\selectfont}
\newcommand\Qdt@TEQnextinterrogationfont{\fontsize{2cm}{2cm}\selectfont}
\newcommand\Qdt@TEQmaintextfont{\sffamily\small}
\newcommand\Qdt@urlforumfont{\sffamily}
\newcommand\Qdt@NDLsubtitlefont{\sffamily\large}
\newcommand\Qdt@NDLtitlebookfont{\sffamily\slshape\bfseries\Large}%
\newcommand\Qdt@NDLsubtitlebookfont{\sffamily\large}%
\newcommand\Qdt@CDPtitlefont{%
  \sffamily\bfseries\fontsize{1.6cm}{1.6cm}\selectfont}
\newcommand\Qdt@CDPabstractfont{\sffamily\large}
\newcommand\Qdt@CDPtitlestatementfont{\bfseries}
\newcommand\Qdt@CDPoldreviewfont{\bfseries}
\newcommand\Qdt@CDPoldstatementfont{\itshape\small}
\newcommand\Qdt@CDPnewstatementfont{\itshape\small}
\newcommand\Qdt@CDPauthornewstatementfont{}
\newcommand\Qdt@ECEtitlefont{\sffamily\fontsize{61}{61}\selectfont}
\newcommand\Qdt@ECEtitleshadefont{\sffamily\fontsize{61}{61}\selectfont}
\newcommand\Qdt@ECEauthorfont{\sffamily\Large}
\newcommand\Qdt@ECEauthorshadefont{\sffamily\Large}
\newcommand\Qdt@ECEsubtitlefont{\sffamily\bfseries\Huge}
\newcommand\Qdt@ECEsubtitleshadefont{\sffamily\bfseries\Huge}
\newcommand\Qdt@ECEabstractfont{\sffamily\slshape\large}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% En-tête et pied de page %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand\Qdt@PageFootEven{%
  \llap{\hbox to5mm{\Qdt@footrulecolor\Qdt@footfont \thepage\hss}}%
  \vspace{-\baselineskip}
  \fboxrule=0pt
  \fboxsep=0pt
  \colorbox{Qdt@footrulecolor}{%
    \Qdt@footfont
    \hbox to17.3cm{%
      \null \vrule width0pt depth1mm height3mm\relax \hfill
      \textcolor{Qdt@textfootrulecolor}{%
        Quadrature \no \@numero\kern6pt}%
    }%
  }%
}
\newcommand\Qdt@PageFootOdd{%
    \fboxrule=0pt
    \fboxsep=0pt
    \colorbox{Qdt@footrulecolor}{%
      \hbox to17.3cm{%
        \Qdt@footfont
        \textcolor{Qdt@textfootrulecolor}{%
          \kern6pt\@magazinemonth{} \@magazineyear}%
        \hfill \vrule width0pt depth1mm height3mm\relax
      }%
    }%
    \rlap{\hbox to5mm{\hss\Qdt@footrulecolor\Qdt@footfont \thepage}}%
}
%
% Pied de page par défaut
%
\fancypagestyle{article}{%
  \fancyhead{}%
  \fancyfoot{}%
  \fancyfoot[LE]{\Qdt@PageFootEven}%
  \fancyfoot[LO]{\Qdt@PageFootOdd}%
  \renewcommand{\headrulewidth}{0pt}%
  \renewcommand{\footrulewidth}{0pt}%
}
%
% Pied de page pour la dernière page des articles
% (pour l'instant, il faut hacker pour équilibrer les colonnes
% et le hack nécessite une redéfinition du pied de page)
%
\newlength{\Qdt@normaltextheight}
\newlength{\Qdt@lastarticlepageheight}
\newlength{\Qdt@GapLastArticlePage}
\AtBeginDocument{\Qdt@normaltextheight \textheight}
\fancypagestyle{lastarticlepage}{%
  \fancyhead{}%
  \fancyfoot{}%
  \fancyfoot[LE]{%
    \setlength{\Qdt@GapLastArticlePage}%
              {\Qdt@normaltextheight-\Qdt@lastarticlepageheight-8.5pt}%
    \vbox to0pt{%
      \kern\Qdt@GapLastArticlePage
      \hbox to\linewidth{\kern-1.9pt\Qdt@PageFootEven}%
      \vss
    }%
  }%
  \fancyfoot[LO]{%
    \setlength{\Qdt@GapLastArticlePage}%
              {\Qdt@normaltextheight-\Qdt@lastarticlepageheight-8.5pt}%
    \vbox to0pt{%
      \kern\Qdt@GapLastArticlePage
      \hbox to\linewidth{\kern-1.9pt\Qdt@PageFootOdd}%
      \vss
    }%
  }%
  \renewcommand{\headrulewidth}{0pt}%
  \renewcommand{\footrulewidth}{0pt}%
}
%
% pied de la première page de la revue
%
\newcommand\FirstQdt@PageFootEven{%
  La première page ne peut pas être sur une page paire
}
\newcommand\Qdt@FirstPageFootOdd{%
    \fboxrule=0pt
    \fboxsep=0pt
      \hbox to\linewidth{%
        \colorbox{Qdt@firstfootrulecolor}{%
          % 2cm = marge ; 5mm = dépassement
        \setlength{\dimen2}{\linewidth+2.5cm}%
        \hbox to\dimen2{\vrule width0pt height3mm depth1mm}
      }\hss
    }%
}
%
%
%
\fancypagestyle{firstpage}{%
  \fancyhead{}%
  \fancyfoot{}%
  \fancyfoot[LE]{\Qdt@FirstPageFootEven}%
  \fancyfoot[LO]{\Qdt@FirstPageFootOdd}%
  \renewcommand{\headrulewidth}{0pt}%
  \renewcommand{\footrulewidth}{0pt}%
}
%
% par défaut le style de page est 'article'
%
\pagestyle{article}%
%
%%%%%%%%%%%%%%%%%
%%% Flottants %%%
%%%%%%%%%%%%%%%%%
%
% Compteur article pour poser les label en première et dernière page
% de chaque article (et récupérer l'information dans la zone DOI)
% Il sert aussi pour la remise à zéro de certains compteurs (donc doit
% être employé par toutes les rubriques)
%
\newcounter{article}
% Remise à zéro des compteurs à chaque article (ou rubrique)
\newcommand\QDT@ResetCounter{%
%  \setcounter{footnote}{0}%
%  \setcounter{allthmlike}{0}%
%  \setcounter{prop}{0}%
%  \setcounter{props}{0}%
%  \setcounter{theo}{0}%
%  \setcounter{theos}{0}%
%  \setcounter{defn}{0}%
%  \setcounter{defns}{0}%
%  \setcounter{lem}{0}%
%  \setcounter{lems}{0}%
%  \setcounter{exo}{0}%
%  \setcounter{exos}{0}%
%  \setcounter{rem}{0}%
%  \setcounter{rems}{0}%
%  \setcounter{coro}{0}%
%  \setcounter{conj}{0}%
%  \setcounter{notation}{0}%
%  \setcounter{notations}{0}%
%  \setcounter{conv}{0}%
%  \setcounter{convs}{0}%
%  \setcounter{app}{0}%
%  \setcounter{apps}{0}%
%  \setcounter{simul}{0}%
%  \setcounter{hyp}{0}%
%  \setcounter{com}{0}%
}
%
% Ajout du flottant 'photo'
%
\newcounter{photo}
\renewcommand \thephoto {\@arabic\c@photo}
\def\ftype@photo{1}
\def\ext@photo{lop} % Pas utile a priori mais bon...
\def\fnum@photo{\photoname\nobreakspace\thephoto}
\newenvironment{photo}
               {\@float{photo}}
               {\end@float}
\newenvironment{photo*}
               {\@dblfloat{photo}}
               {\end@dblfloat}
%
% Numérotation des flottants et autres structures
% remis à zéro à chaque article (ou rubrique)
%
\@addtoreset{figure}{article}
\@addtoreset{photo}{article}
\@addtoreset{table}{article}
\@addtoreset{allthmlike}{article}
\@addtoreset{footnote}{article}
%
% Placement par défaut des flottants
%
\def\fps@figure{htp}
\def\fps@photo{htp}
\def\fps@table{htp}
%
% Pas de petites capitales pour les titres de légende
%
\addto\captionsfrench{\def\figurename{Figure}}
\addto\captionsfrench{\def\photoname{Photographie}}
\addto\captionsfrench{\def\tablename{Tableau}}
%
% Redéfinition de la commande de formattage des légende pour avoir :
% - les couleurs adéquat ;
% - le point comme séparateur et pas de point si pas de légende (juste
%   « Figure 1 » par exemple) ;
% - la légende est centrée si elle fait une seule ligne, justifiée
%   autrement.
%
\def\Qdt@emptycaption{\ignorespaces}%
\long\def\@makecaption#1#2{%
  \def\Qdt@temp{#2}%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{%
    \Qdt@captioncolor
    \Qdt@captionfont
    \ifx\Qdt@temp\Qdt@emptycaption
      #1
    \else
      #1. #2
    \fi
  }%
  \ifdim \wd\@tempboxa >\hsize
    {%
      \Qdt@captioncolor
      \Qdt@captionfont
      \ifx\Qdt@temp\Qdt@emptycaption
        #1
      \else
        #1. #2
      \fi
      \par
    }%
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip
}
%
% Commandes pour avoir des légendes sans type et sans numéro
%
\def\simplecaption{%
   \ifx\@captype\@undefined
     \@latex@error{\noexpand\simplecaption outside float}\@ehd
     \expandafter\@gobble
   \else
     \expandafter\@firstofone
   \fi
   {\@dblarg{\@simplecaption\@captype}}%
}
\long\def\@simplecaption#1[#2]#3{%
  \par
  \begingroup
    \@parboxrestore
    \if@minipage
      \@setminipage
    \fi
    \normalsize
    \@makesimplecaption{#3}\par
  \endgroup
}
\long\def\@makesimplecaption#1{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{%
    \Qdt@captioncolor
    \Qdt@captionfont
      #1
  }%
  \ifdim \wd\@tempboxa >\hsize
    {%
      \Qdt@captioncolor
      \Qdt@captionfont
        #1
      \par
    }%
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Modification locale de marge %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Marge de côté
%
\newenvironment{changemargin}[2]{%
  \begin{list}{}{%
      \setlength{\topsep}{0pt}%
      \setlength{\leftmargin}{#1}%
      \setlength{\rightmargin}{#2}%
      \setlength{\listparindent}{\parindent}%
      \setlength{\itemindent}{\parindent}%
      \setlength{\parsep}{\parskip}%
    }%
  \item[]}
  {\end{list}}
%
% Pour les notes de fin d'article, il faut passer par la commande
% \LastNote qui mémorise les corps de note dans la macro
% \QDT@footnote
\newcount\QDT@nbnote % Nombre de notes
\newcommand\QDT@footnote{}%
\newcommand\LastNote[1]{%
  \global\advance\QDT@nbnote\@ne % pour tester s'il y a des notes ou non.
  \protected@xdef\QDT@footnote{%
    \QDT@footnote
    \protect\QDT@new@note % Code à placer entre chaque note
    #1
  }%
}
%
\newcommand\QDT@new@note{%
  \par\stepcounter{footnote}%
  \thefootnote.
}
% Équilibre des colonnes de la dernière page.
\ifQDT@experimental
  % En version experimentale, la commande \BalanceColumn ne sert plus
  % à rien. On la garde en tant que coquille vide pour ne pas empêcher
  % les compilations d'anciens documents
  \newcommand\BalanceColumn[1]{}
  % Pour la même raison, on modifie également ces deux paramètres afin
  % de ne pas modifier les mises en pages d'anciens documents.
  \renewcommand\textfraction{0.01}
  \renewcommand\bottomfraction{0.99}
  % En revanche, on crée la commande \QDT@Automatic
  \newcommand\QDT@AutomaticBalancedColumn{%
    \ifnum\QDT@nbnote>0
      \addtocounter{footnote}{-\QDT@nbnote}%
      \par
      \noindent\rule{0.5\linewidth}{0.4pt}%
      \begingroup
        \footnotesize
        \QDT@footnote\par\vspace{-\baselineskip}
      \endgroup
    \fi
    \begin{strip}
      \null \par
    \end{strip}
    \par\vspace*{\stretch{1}}
  }
\else
  % En mode non expérimental il faut placer cette commande avant la
  % fin de la première colonne (équilibrée). L'argument indique la
  % place qui ne sera pas prise par le texte en fin de
  % page. L'espacement doit être au moins de 20pt.
  \def\fps@QDTbalance{b} % En bas de page par défaut
  \def\ftype@QDTbalance{8} % ni 1 ni 2 ni 4 (réservé par d'autres
                           % flottants) 
  \def\ext@QDTbalance{} % pas besoin de liste
  \def\fnum@QDTbalance{} % pas besoin de légende
  \newenvironment{QDTbalance}
                 {\@float{QDTbalance}}
                 {\end@float}
  \newenvironment{QDTbalance*} % Normalement inutile mais sait-on jamais
                 {\@dblfloat{QDTbalance}}
                 {\end@dblfloat}
  %
  % \BalanceColumn utilise le flottant QDTbalance
  % Il place un flottant en bas des deux colonnes d'une page pour forcer
  % ces deux colonnes à avoir la même hauteur (la place restante sur la
  % page).
  % 
  \newcommand\BalanceColumn[1]{%
    \setlength{\dimen@}{#1-20pt}% 20 pt pour les espacements avant le
                                % flottant
    \begin{QDTbalance} % Les flottants de fin de page sont permis grâce à
                      % l'extension dblfloatfix
      \rule{\Qdt@widthBalance}{\dimen@}%
    \end{QDTbalance}%
    \afterpage{% Il faut le faire sur les deux colonnes
      \begin{QDTbalance}
        \rule{\Qdt@widthBalance}{\dimen@}%
      \end{QDTbalance}%
    }%
  }
  % Pour permettre de placer les flottants quel que soit la hauteur de
  % texte restant, on donne des valeurs extrêmes à deux paramètres de
  % contrôle des flottants. Le paramètre \dblbottomfraction n'existe pas
  % puisque normalement on ne peut pas placer des flottants de bas de
  % page en double-colonne. L'extension dblfloatfix ne crée pas une
  % telle macro mais utilise le paramètre \bottomfraction. De même,
  % \textfraction est valable en une ou deux colonnes.
  \renewcommand\textfraction{0.01}
  \renewcommand\bottomfraction{0.99}
  % 
  % Pour mieux comprendre ce qui se passe, \showBalance montre les filets
  % 
  \newcommand\showBalance{%
    \def\Qdt@widthBalance{0.4pt}%
  }
  \newcommand\hideBalance{%
    \def\Qdt@widthBalance{0pt}%
  }
  % Par défaut, on ne vois pas les filets
  \def\Qdt@widthBalance{0pt}
\fi
%
%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Textes avec ombre %%%
%%%%%%%%%%%%%%%%%%%%%%%%%
%
\catcode`\;=13
\newcommand\Qdt@TextShadow[3]{%
  \tikz\Qdt@@TextShadow{#1}{#2}{#3};
}
\def\Qdt@@TextShadow#1#2#3;{%
  % #1 = couleur et style pour le texte
  % #2 = couleur et style pour l'ombre
  % #3 = texte
  \node[above, yscale=-0.85, inner sep=-0.2pt, xslant=0.9,
        lightgray]{%
          \setbox0=\hbox{%
            \csname Qdt@#2color\endcsname
            \csname Qdt@#2font\endcsname
            #3%
          }%
          \dp0=0pt
          \box0
        };
  \node[above, inner sep=-0.2pt]{%
    \setbox0=\hbox{%
      \csname Qdt@#1color\endcsname
      \csname Qdt@#1font\endcsname
      #3%
    }%
    \dp0=0pt
    \box0
  };
}%

\newcommand\Qdt@FirstLetterShadow[4]{%
  % #1 = couleur et style pour le texte
  % #2 = couleur et style pour l'ombre
  % #3 = première lettre
  % #4 = reste du texte (sans ombre)
  \tikz\Qdt@@FirstLetterShadow{#1}{#2}{#3}#4;
}
\def\Qdt@@FirstLetterShadow#1#2#3#4;{%
  \node[above, yscale=-0.85, inner sep=-0.2pt, xslant=0.9,
        lightgray]{%
          \setbox0=\hbox{%
            \csname Qdt@#2color\endcsname
            \csname Qdt@#2font\endcsname
            #3%
          }%
          \dp0=0pt
          \box0
        };
  \node[above, inner sep=-0.2pt](X){%
    \setbox0=\hbox{%
      \csname Qdt@#1color\endcsname
      \csname Qdt@#1font\endcsname
      #3%
    }%
    \dp0=0pt
    \box0
  };
  \node[above right, inner sep=-0.2pt] at (X.south east){%
    \setbox0=\hbox{%
      \csname Qdt@#1color\endcsname
      \csname Qdt@#1font\endcsname
      #4%
    }%
    \dp0=0pt
    \box0
  };
}%
\catcode`\;=12
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Gestion de \thanks à l'intérieur des rubriques %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\let\thanks\relax % Valeur par défaut (pour le non développement)
\newtoks\Qdt@hookfootnote
%
% \Qdt@DefineThanks met en place le mécanisme pour afficher les appels
% de note et sauvegarder les corps de note. Cette macro doit être
% placée juste avant \twocolumn[...]
%
\newcommand*\Qdt@DefineThanks{%
  \setcounter{footnote}{0}%
  \global\Qdt@hookfootnote{}%
  \def\thanks##1{%
    \footnotemark
    \global\Qdt@hookfootnote\expandafter{%
      \the\Qdt@hookfootnote
      \stepcounter{footnote}%
      \footnotetext{##1}%
    }%
  }%
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \def\@makefnmark{\!\hbox{\@textsuperscript{\normalfont\@thefnmark}}}%
  \long\def\@makefntext##1{%
    \parindent 1em\noindent
    \hb@xt@1.8em{%
      \hss\@textsuperscript{\normalfont\@thefnmark}%
    }%
    ##1%
  }%
}
%
% \Qdt@UseThanks affiche les notes de bas de page. Cette macro doit
% être appelée juste après le \twocolumn[...]
%
\newcommand*\Qdt@UseThanks{%
  \setcounter{footnote}{0}%
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \def\dotFFN{}%
  \the\Qdt@hookfootnote
  % Code suivant réalisé avant le résumé quand il existe.
  % \def\dotFFN{.}%
  % \setcounter{footnote}{0}%
  % \renewcommand\thefootnote{\@arabic\c@footnote}%
}
\newcommand*\Qdt@UseThanksBis{%
  \setcounter{footnote}{0}%
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \def\dotFFN{}%
  \the\Qdt@hookfootnote
  % Code suivant non réalisé car pas de résumé.
  \def\dotFFN{.}%
  \setcounter{footnote}{0}%
  \renewcommand\thefootnote{\@arabic\c@footnote}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la première page %%%
%%% (personnes, sommaire, éditorial) %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Gestion des auteurs multiples
%
\let\and\relax
\newcommand*\Qdt@TypesetFirstPageAuthor[1]{%
  \Qdt@nbAuthor \z@
  \expandafter\Qdt@@TypesetFirstPageAuthor#1\and\stop
  \let\next\Qdt@@@TypesetFirstPageAuthor
  \expandafter\next#1\and
}
\def\Qdt@@TypesetFirstPageAuthor#1\and#2\stop{%
  \advance\Qdt@nbAuthor \@ne
  \ifx\relax#2\relax
    \else
    \Qdt@@TypesetFirstPageAuthor#2\stop
  \fi
}
\def\Qdt@@@TypesetFirstPageAuthor#1\and{%
  \leavevmode\hbox{#1}\unskip
  \advance\Qdt@nbAuthor \m@ne
  \ifnum\Qdt@nbAuthor>\@ne
    ,\\
  \else\ifnum\Qdt@nbAuthor=\@ne
%      ~et\\ % que des virgules
    ,\\
  \else
    \let\next\relax
  \fi\fi
  \next
}
%
% Gestion des éléments de la page avec un système de <clé>=<valeur>
% Les clés suivantes sont disponibles :
% - title -> fonction (en couleur)
% - titlerun -> même chose que ci-dessus sans passage à la ligne
% - author -> personne(s) (séparées par \and) à la suite du titre
% - freetext -> texte libre à la suite du titre
% - vfill -> insertion d'un espace vertical infiniment élastique.
%           Cette clé demande une valeur numérique (correspondant au
%           paramètre de \stretch) avec une valeur par défaut = 1.
% - editorialauthor -> nom de l'éditorialiste (seul champ obligatoire)
% - editorial -> contenu de l'éditorial (ce qui est ccompris entre les
% grosses double quotes anglaise).
%
% Les cinq premières clés sont un peu particulières puisqu'elles
% entassent du contenu dans le registre d'UL \@distribution
\newtoks\@distribution
% et peuvent (doivent) être répétées pour construire petit à petit la
% colonne de gauche (sauf le texte avant « Rédacteur en chef » qui est
% automatique.
\define@key{firstpage}{title}{%
  \@distribution\expandafter{%
    \the\@distribution
    \par\vskip 4mm plus2mm minus4mm\relax
    {%
      \Qdt@titledistributionfont
      \Qdt@titledistributioncolor
      #1\par
    }%
  }%
}
\define@key{firstpage}{titlerun}{%
  \@distribution\expandafter{%
    \the\@distribution
    \par\vskip8mm plus2mm minus4mm\relax
    {%
      \Qdt@titledistributionfont
      \Qdt@titledistributioncolor
      #1%
    }%
  }%
}
\define@key{firstpage}{author}{%
  \@distribution\expandafter{%
    \the\@distribution
    {%
      \Qdt@authordistributionfont
      \Qdt@authordistributioncolor
      \Qdt@TypesetFirstPageAuthor{#1}%
      \par
    }%
  }%
}
\define@key{firstpage}{freetext}{%
  \@distribution\expandafter{%
    \the\@distribution
    {%
      \Qdt@authordistributionfont
      \Qdt@authordistributioncolor
      #1\par
    }%
  }%
}
\define@key{firstpage}{vfill}[1]{%
  \@distribution\expandafter{%
    \the\@distribution
    \par\vspace{0pt plus#1fill}%
  }%
}
\define@key{firstpage}{editorialauthor}{%
  \def\@editorialauthor{#1}%
}
\define@key{firstpage}{editorial}{%
  \long\def\@editorial{#1}%
}
%
% Environnement construisant la première page de la revue
%
% \onecolumn saute une page, il ne faut pas :
\def\QDT@onecolumn{%
%  \clearpage
  \global\columnwidth\textwidth
  \global\hsize\columnwidth
  \global\linewidth\columnwidth
  \global\@twocolumnfalse
  \col@number \@ne
  \@floatplacement}
% Ajout du bulletin dans la toc
% Commande à placer à la toute fin du fichier principal
\newcommand\AddBulletin[1]{%
  \addtocontents{toc}{%
    \protect\contentsline
    {article}%
    {%
      \protect\Qdt@titletocarticlecolor
      \protect\Qdt@titletocarticlefont
      Bulletin d'abonnement%
    }%
    {#1}%
  }%
}
\newenvironment{FirstPage}[1][]
{%
  % Pas de double colonne pour la première page (les pseudo-colonnes
  % sont de largeurs différentes et seront traitées avec des
  % minipages).
  \mbox{}\newpage % encore une TeXerie que je ne comprends pas mais
                  % sans ça, la p. 1 reste blanche
  \setcounter{page}{3}% On commence en page 3 !
  \thispagestyle{firstpage}
  \QDT@onecolumn
  \pagestyle{empty}
  \parindent \z@
  % registre d'unité lexicale vide en début de travail
  \@distribution{}%
  % Valeurs par défaut des clés
  \def\@editorialauthor{\@latex@error{No editorialauthor
      given}\@ehc}%
  % Récupération des valeurs des clés
  \setkeys{firstpage}{#1}%
  % Fabrication effective de la page
  % Colonne de gauche
  % Cette colonne (en fait le premier truc qu'on place dans la page)
  % est situé environ 2,18 cm au-dessous de sa position à laquelle on
  % est en droit de s'attendre. Je n'ai pas (encore) compris
  % pourquoi. Cela explique la hauteur bizarre de la minipage. La
  % minipage de deuxième colonne n'a pas besoin de cette correction.
  % \begin{minipage}[t][25.8cm]{5.8cm}
  \begin{minipage}[t][25.9cm]{5.8cm}
    \hbox{%
      \kern8mm
      \includegraphics[width=1.5cm]{logoBW}%
    }%
    \par\vspace{2mm}
    \hbox{%
      \Qdt@titlereviewfont
      \Qdt@titlereviewcolor
      Quadrature
    }%
    \par\addvspace{8mm plus2mm minus4mm}
    {%
      \Qdt@authordistributionfont
      \Qdt@authordistributioncolor
      Trimestriel -- Numéro \@numero\par
      \@magazinemonth{} \@magazineyear
    }
    \par
    \raggedright
    \the\@distribution
  \end{minipage}%
  {%
    \Qdt@frameeditorialcolor
    \vbox to0pt{%
      % Cela correspond environ à 5mm de débordement en haut
      \kern-3cm
      \hsize=1pt
      % 30.7 = 29.7 + 2*0.5 => dépassement de 5mm en bas
      \vrule height30.7cm width 1pt
    }%
    \kern-1pt
  }%
  % colonne de droite
  \begin{minipage}[t][25cm]{\textwidth-5.8cm}%
    % sommaire
    \setbox0=\hbox{%
      \begin{minipage}[t]{\textwidth-3.4cm}
        {%
          \Qdt@titletocfont
          \Qdt@titletoccolor
          Sommaire
        }%
        \@starttoc{toc}
      \end{minipage}%
    }%
    \vspace*{-5mm}%
    \hspace*{1.7cm}%
    \copy0
    \par\vspace{12pt}
    % Éditorial
    % rectangle largeur = 9.5cm + 3.7cm de marge + 5mm de pleine page
    \begin{tikzpicture}
      \draw[use as bounding box] (0,0) rectangle (0,0);
      \draw[color=Qdt@frameeditorialcolor,
            fill=Qdt@frameeditorialcolor]
              (0,0) rectangle (13.7,-15);
    \end{tikzpicture}%
    \color{Qdt@textframeeditorialcolor}
    \par\vspace{4mm}\hspace*{2mm}%
    {%
      \Qdt@quoteeditorialfont
      \raisebox{-13.35mm}{``}% %''
    }%
    % titre de l'éditorial
    {%
      \Qdt@titleeditorialfont
      \space\'Editorial
    }%
    {%
     \Qdt@authoreditorialfont
      Par \@editorialauthor
    }\par\vspace{-12pt}
    % texte de l'éditorial
    \hspace*{8mm}%
    \begin{minipage}{11cm}%
      \Qdt@editorialfont
      \parskip=6pt plus4pt minus3pt
      \@editorial
      \par\vspace{-24pt}
      \null\hfill
      {%
        \Qdt@quoteeditorialfont
        ''\hspace*{-1mm}%
      }%
    \end{minipage}\hss
  \end{minipage}%
}
{\twocolumn}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la rubrique %%%
%%%            Forum            %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% auteur d'un article interne au forum
%
\newcommand*\signatureauteurforum[1]{%
  \par\null\hfill\textbf{#1}
  \par\addvspace{24pt plus8pt minus4pt}
}
%
% Pas d'auteurs généraux => pas besoin de clé
% on démarre immédiatement l'environnement
%
\newenvironment{forum}
{%
  \newpage
  \refstepcounter{article}% Précaution pour remettre tous les
                          % compteurs de plan à zéro
  % remet tous les compteurs (footnote et thmslikes, etc. à zéro)
  \QDT@ResetCounter
  \twocolumn[%
    {% pour protéger les crochets de la commande \makebox
      % Point d'interrogation en blanc dans l'ellipse en pleine page
      % L'emplacement dépend de la parité de la page.
      \ifodd\c@page
      % cas impair : ellipse à droite
        \makebox[0pt][l]{%
          \hspace*{\linewidth}% positionnement sur la marge droite
          \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
          \smash{%
            \raisebox{-20mm}{%
              \includegraphics{ellipse}%
%              \tikz \draw[color=Qdt@TEQellipsecolor,fill=Qdt@TEQellipsecolor]
%                (0,0) ellipse (1.5cm and 1.9cm);
            }%
          }%
        }%
      \else
        % cas pair : ellipse à gauche
%      \begin{tikzpicture}
%        \draw[color=Qdt@TEQellipsecolor,fill=Qdt@TEQellipsecolor]
%          (0,0) ellipse (1.5cm and 1.9cm);
%      \end{tikzpicture}
        \makebox[0pt][r]{%
          \smash{%
            \raisebox{-20mm}{%
%              \begin{pspicture}(0,0)(3,3.8)
%                \psellipse*[linecolor=Qdt@TEQellipsecolor](1.5,1.9)(1.5,1.9)
%              \end{pspicture}
              \includegraphics{ellipse}%
            }%
          }%
          \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
        }%
      \fi
      {%
        \Qdt@titlerubricfont\Qdt@titlerubriccolor
        Forum
        \par
      }%
      \addcontentsline{toc}{article}{%
        \protect\Qdt@titletocarticlecolor
        \protect\Qdt@titletocarticlefont
        Forum%
      }%
      \vskip5mm\relax
      {%
        \Qdt@urlforumfont
        contact@quadrature.info
      }%
      \par\vskip1.5cm\relax
    }%
  ]%
  % Dans cette rubrique, les sections ne sont pas numérotées
  \setcounter{secnumdepth}{-2}%
  % et centrée (redéfinition avec les mêmes valeurs sauf \centering)
  \renewcommand\section{\@startsection
    {section}%
    {1}%
    {\z@}%
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {%
      \Qdt@sectioncolor
      \Qdt@sectionfont
      \Qdt@section@centering{section}%
    }%
  }
}
% Pose de l'étiquette de fin de rubrique.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la rubrique %%%
%%%  Envers et contre-exemples  %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Gestion des auteurs multiples
%
\newcommand*\Qdt@TypesetECEAuthor[1]{%
  \gdef\Qdt@ECEAuthor{}%
  \Qdt@nbAuthor \z@
  \expandafter\Qdt@@TypesetECEAuthor#1\and\stop
  \let\next\Qdt@@@TypesetECEAuthor
  \expandafter\next#1\and
}
\def\Qdt@@TypesetECEAuthor#1\and#2\stop{%
  \advance\Qdt@nbAuthor \@ne
  \ifx\relax#2\relax
    \else
    \Qdt@@TypesetECEAuthor#2\stop
  \fi
}
\def\Qdt@@@TypesetECEAuthor#1\and{%
  \protected@xdef\Qdt@ECEAuthor{\Qdt@ECEAuthor #1\unskip}%
  \advance\Qdt@nbAuthor \m@ne
  \ifnum\Qdt@nbAuthor>\@ne
    \protected@xdef\Qdt@ECEAuthor{\Qdt@ECEAuthor, }%
  \else\ifnum\Qdt@nbAuthor=\@ne
    \protected@xdef\Qdt@ECEAuthor{\Qdt@ECEAuthor\space et }%
  \else
    \let\next\relax
  \fi\fi
  \next
}
%
% Gestion de l'en-tête avec une syntaxe <clé>=<valeur>
% Les clés suivantes sont disponibles :
% - author -> Liste des auteurs séparés par des \and.
%             Pour l'instant, l'auteur par défaut est
%             Bertrand Hauchecorne
% - subtitle -> Sous-titre (avec sa première lettre soulignée). Il
%               vaut mieux que le titre soit saisi avec la première
%               lettre entre accolades (c'est essentiel si la première
%               lettre est accentuée et que le codage est UTF-8)
%
\define@key{ECE}{author}{\gdef\ECE@Author{#1}}
\define@key{ECE}{title}{\ECE@splittitle#1\stop}
\define@key{ECE}{spaceafterabstract}{\setlength{\QDT@spaceafterabstract}{#1}}
\def\ECE@splittitle#1#2\stop{%
  \gdef\ECE@FirstTitle{#1}%
  \gdef\ECE@NextTitle{#2}%
}%
%
% Environnement général pour la rubrique
%
\newenvironment{ECE}[1][]%
{%
  \newpage % Précaution pour le \refstepcounter qui suit
  % Numéro de rubrique en cours (nécessaire pour réinitialiser
  % certains compteurs)
  \refstepcounter{article}
  % remet tous les compteurs (footnote et thmslikes, etc. à zéro)
  \QDT@ResetCounter
  % Remise aux valeurs par défaut des clés avant leur lecture
  \def\ECE@Author{Bertrand Hauchecorne}%
  \def\ECE@FirstTitle{}%
  \def\ECE@NextTitle{}%
  \setlength{\QDT@spaceafterabstract}{9mm}
  % Récupère toutes les informations (auteur(s) et résumé éventuel)
  \setkeys{ECE}{#1}%
  % Mise en forme de l'en-tête
  \twocolumn[%
    \noindent
    % Mini correction pour que le mini-dépassement dans les marges
    % soient bien symétriques
    \hspace*{-1mm}%
    \Qdt@TextShadow{ECEtitle}{ECEtitleshade}{%
      \scalebox{-1}[1]{\rotatebox[y=0.52ex]{180}{envers}}}%
    % Espace vertical entre « envers » et «et contre-exemples»
    \par\vspace{6mm}%
    \noindent\hspace*{-1mm}%
    \Qdt@TextShadow{ECEtitle}{ECEtitleshade}{%
      \scalebox{-1}[1]{\rotatebox[y=0.52ex]{180}{et contre-exemples}}}%
    % Ajout du titre dans la toc
    \addcontentsline{toc}{article}{%
      \protect\Qdt@titletocarticlecolor
      \protect\Qdt@titletocarticlefont
      Envers et contre-exemples%
    }%
    % Espace entre le titre et le résumé (fixe ?)
    % Si le résumé venait à changer, on peut toujours le mettre en
    % clé avec une valeur par défaut égal au texte ci-dessous.
    \par\vspace{6mm}\noindent
    {%
      \Qdt@ECEabstractcolor
      \Qdt@ECEabstractfont
      Qu'il soit rebelle ou impertinent, pédagogique ou fondamental, le
      contre-exemple montre les forces et les limites d'une
      théorie. Combien de fois n'a-t-il pas ébranlé des idées qui
      semblaient pourtant établies ?
    }
    % Normalement il y a forcément un auteur mais sait-on jamais
    \unless\ifx\@author\empty
      \par\noindent
      {%
        % Ajout de l'auteur dans la TDM
        \addtocontents{toc}{\protect\l@author{\ECE@Author}}%
        \Qdt@TypesetECEAuthor{\ECE@Author}%
        % Pour cadrer à droite en laissant dépasser l'ombre, il faut
        % ajouter une espace négative tout à la fin.
        \hfill
        \Qdt@TextShadow{ECEauthor}{ECEauthorshade}{Par \Qdt@ECEAuthor}%
        \hspace*{-4.1mm}%
        \par
      }%
      % Espace entre l'auteur et le titre de la rubrique (qui est plus
      % un sous-titre en fait !
      \par\vspace{\QDT@spaceafterabstract}
    \fi
    \begin{center}
      % Version avec première lettre ombrée
%      \Qdt@FirstLetterShadow{ECEsubtitle}{ECEsubtitleshade}
%          {\ECE@FirstTitle}{\ECE@NextTitle}%
      % Version sans première lettre ombrée
      \Qdt@ECEsubtitlecolor \Qdt@ECEsubtitlefont
      \ECE@FirstTitle\ECE@NextTitle
      % Fin des versions
    \end{center}
    % Aucun espace supplémantaire prévu entre le sous-titre et le
    % début de l'article
    \par
  ]
  % Dans cette rubrique, les sections ne sont pas numérotées
  \setcounter{secnumdepth}{-2}%
  % 
}
% Pose de l'étiquette de fin de rubrique.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la rubrique %%%
%%%     Textes en questions     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Gestion des auteurs multiples
%
% Pour l'instant comme dans Article donc on emploiera la macro
% \Qdt@TypesetArticleAuthor
%
% Seule la clé author est permise dans cette rubrique
%
\define@key{TEQ}{author}{%
  \gdef\@author{#1}%
  \ifx\relax#1\relax
  \else
    \addtocontents{toc}{\protect\l@author{#1}}%
  \fi
}
%
% Point d'interrogation repris à trois reprises
%
\newcommand\Qdt@TEQinterrogation{%
  {\usefont{T1}{yvt}{m}{n}?}%
}
\newcommand\Qdt@TEQbfinterrogation{%
  {\usefont{T1}{yvt}{b}{n}?}%
}
%
% TEQquestion pour les questions encadrées en début de rubrique
%
\newenvironment{TEQquestion}
{%
  \colorlet{shadecolor}{Qdt@TEQframecolor}%
  \setlength{\FrameSep}{0pt}
  \begin{shaded}
  \changemargin{3mm}{3mm}
  \vskip3mm\relax
  \color{Qdt@TEQtextframecolor}%
  \ignorespaces
}
{%
  \par\vskip3mm\relax
  \endchangemargin\end{shaded}%
}
%
% TEQnext pour l'encadré en fin de rubrique
%
\newenvironment{TEQnext}
{%
  \colorlet{shadecolor}{Qdt@TEQframecolor}%
  \setlength{\FrameSep}{0pt}
  \begin{shaded}
  \changemargin{3mm}{3mm}
  \vskip3mm\relax
  \makebox[0pt][l]{%
    \hspace*{\linewidth}% les 2 premiers pour être au niveau de
    \hspace*{-\parindent}% la marge droite
    \hspace*{0.8mm}% réglage fin
    \smash{%
      \raisebox{-10mm}{%
        \Qdt@TEQnextinterrogationfont
        \Qdt@TEQinterrogation
      }%
    }%
  }%
  \color{Qdt@TEQtextframecolor}%
  \ignorespaces
}
{%
  \par\vskip3mm\relax
  \endchangemargin\end{shaded}%
}
%
% Environnement pour la rubrique Textes en questions
%
\newenvironment{TEQ}[1][]
{%
  \newpage
  \refstepcounter{article}% Précaution pour remettre tous les
                          % compteurs de plan à zéro
  % remet tous les compteurs (footnote et thmslikes, etc. à zéro)
  \QDT@ResetCounter
  \Qdt@TEQmaintextfont
  \setkeys{TEQ}{#1}
  \twocolumn[%
  \sffamily
  {% pour protéger les crochets de la commande \makebox
    % Point d'interrogation en blanc dans l'ellipse en pleine page
    % L'emplacement dépend de la parité de la page.
    \ifodd\c@page
      % cas impair : ellipse à droite
      \makebox[0pt][l]{%
        \hspace*{\linewidth}% positionnement sur la marge droite
        \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
        \smash{%
          \raisebox{-20mm}{%
            \includegraphics{ellipse}%
          }%
        }%
        % positionnement du point d'interrogation
        \smash{%
          \hspace*{-2.6cm}%
          \raisebox{-8mm}{%
            \Qdt@TEQellipseinterrogationcolor
            \Qdt@TEQellipseinterrogationfont
            \Qdt@TEQinterrogation
          }%
        }%
      }%
    \else
      % cas pair : ellipse à gauche
      \makebox[0pt][r]{%
        \smash{%
          \raisebox{-20mm}{%
            \includegraphics{ellipse}%
          }%
        }%
        \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
      }%
      \makebox[0pt][r]{%
        % positionnement du point d'interrogation
        \smash{%
          \raisebox{-8mm}{%
            \hspace*{-1.2cm}%
            \Qdt@TEQellipseinterrogationcolor
            \Qdt@TEQellipseinterrogationfont
            \Qdt@TEQinterrogation
          }%
        }%
        \hspace*{0.7cm}%
      }%
    \fi
    \makebox[0pt][l]{% Gros point d'interrogation sous le titre
      \hspace*{9cm}%
      \smash{%
        \raisebox{-98mm}{%
          \Qdt@TEQtitleinterrogationfont
          \Qdt@TEQtitleinterrogationcolor
          \Qdt@TEQinterrogation
        }%
      }%
    }%
  }%
  {%
    \Qdt@titlerubricfont\Qdt@titlerubriccolor
    \hspace*{5mm}Textes\\[-3mm]en questions
    \par
  }
  \addcontentsline{toc}{article}{%
    \protect\Qdt@titletocarticlecolor
    \protect\Qdt@titletocarticlefont
    Textes en questions%
  }%
  \vspace{5mm}
  {%
    \Qdt@TEQsubtitlefont
    \Qdt@TEQsubtitlecolor
    Les textes empruntés à l'histoire des mathématiques\\
    font notre actualité
    \par
  }
  \ifx\relax\@author\relax\else
    \par\vspace{12mm}
    {%
      \Qdt@authorfont\Qdt@authorcolor 
      Par \Qdt@TypesetArticleAuthor{\@author}
    }%
  \fi
  \par\vspace{10mm}
  Cette rubrique de \emph{Quadrature} propose d'offrir aux lecteurs une
  approche des problèmes de mathématiques par les textes originaux.
  Chaque numéro comporte une « Question mathématique » (l'énoncé
  commenté d'un problème tel qu'il fut posé par le passé) et une
  «Question historique » (détail d'un des aspects ou champs
  disciplinaires impliqués dans le problème posé). Les lecteurs sont
  invités à répondre à ces questions et les meilleures suggestions
  seront incorporées à celles des auteurs dans le numéro suivant.
  \par\vspace{12mm}
  ]
}
% Pose de l'étiquette de fin de rubrique.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la rubrique %%%
%%%       Notes de lecture      %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Commande pour composer le titre d'un livre
%
\newcommand\Qdt@Typesettitlebook{%
  {%
    \par\vspace{1.5cm plus 5mm minus 5mm}%
    \noindent\raggedright
    \Qdt@NDLtitlebookcolor
    \Qdt@NDLtitlebookfont
    % \\ ne doit pas être développé
    \let\\\relax
    % Titre vide au départ
    \def\@@NDLtitle{}%
    % Constructeur du titre (le but est de récupérer la longueur de la
    % dernière ligne pour le souligner)
    \expandafter\Qdt@@Typesettitlebook\@NDLtitle\\\STOP \\%
    % Affichage du titre
    \@@NDLtitle
    \par\nobreak
  }%
}
% appel récursif, on récupère une ligne et on la met en boîte
% à la fin, on utilise la boîte construite à l'appel précédent pour
% connaître la largeur du filet 
\def\Qdt@@Typesettitlebook#1\\{%
  \ifx\STOP#1%
    % il n'y a plus rien => travail terminal
    % Place le filet dans le titre
    \protected@edef\@@NDLtitle{%
      \@@NDLtitle
      \vspace{-6pt}\nobreak
      \rule[12pt]{\wd0}{1pt}%
      \par\nobreak
    }%
    % Pas d'appel récursif
  \else
    % une ligne est lue :
    % - on la place à la fin de \@@NDLtitle (avec un saut de ligne)
    \protected@edef\@@NDLtitle{\@@NDLtitle#1\newline}%
    % - on la met en boîte (au cas où se serait la dernière)
    \setbox0=\hbox{#1}%
    % Appel récursif
    \expandafter\Qdt@@Typesettitlebook
  \fi
}
%
% Commande pour composer les auteurs.
% un seul auteur par ligne séparé par une virgule
\newcommand*\Qdt@TypesetNDLauthor{%
  % Super simple si on suit la mise en page du 79 :
  % Redéfinition facile du \and
  \def\and{,\newline}%
  % Plus compliqué (du type article) si on suit la mise en page
  % d'autres numéros.
}
%
% Commande pour composer le titre du livre et tous les renseignements
% afférents
%
\define@key{NDL}{titre}{\def\@NDLtitle{#1}}
\define@key{NDL}{auteurlivre}{\def\@NDLauthor{#1}}
\define@key{NDL}{editeur}{\def\@NDLeditor{#1}}
\define@key{NDL}{prix}{\def\@NDLprice{#1}}
\define@key{NDL}{isbn}{\def\@NDLISBN{#1}}
\define@key{NDL}{auteurndl}{\def\@NDLsign{#1}}
\define@key{NDL}{couverture}{\def\@NDLcover{#1}}
\define@key{NDL}{largeurcouverture}{\def\@NDLhcover{#1}}
\define@key{NDL}{hauteurcouverture}{\def\@NDLvcover{#1}}
\newenvironment{livre}[1][]
{%
  % Valeurs des clés vides par défaut
  \def\@NDLtitle{}%
  \def\@NDLauthor{}%
  \def\@NDLeditor{}%
  \def\@NDLprice{}%
  \def\@NDLISBN{}%
  \def\@NDLsign{}%
  \def\@NDLcover{}%
  \def\@NDLhcover{3cm}% par défaut les couvertures feront 3cm
  \def\@NDLvcover{}%
  %  Lecture des clés
  \setkeys{NDL}{#1}%
  % Composition du titre
  \Qdt@Typesettitlebook
  % S'il y a une couverture, elle doit être habillée par le texte
  % (sous-titre et début du texte).
  \ifx\empty\@NDLcover\else
    \ifx\empty\@NDLvcover
      \setbox0=\hbox{\includegraphics[width=\@NDLhcover]{\@NDLcover}}%
      \dimen@=\ht0
      \advance\dimen@ \dp0
      \edef\@NDLvcover{\the\dimen0}%
    \fi
    \dimen@=\@NDLvcover
    \advance\dimen@ -12pt % (espace non pris en compte par wrapfig)
    \dimen2=12pt
    \divide\dimen@ by \dimen2
    \count@=\dimen@
    \begin{wrapfigure}[\the\count@]{r}{\@NDLhcover}
      \vspace{-15pt}%
      \includegraphics[width=\@NDLhcover]{\@NDLcover}
      \vspace{-12pt}%
    \end{wrapfigure}
  \fi
  % Dans tous les cas, affichage du sous-titre
  \par\noindent
  {%
    \Qdt@NDLsubtitlebookcolor
    \Qdt@NDLsubtitlebookfont
    \Qdt@TypesetNDLauthor\@NDLauthor
    \newline \@NDLeditor, \@NDLprice
    % certaines entrées ne sont pas des livres (et n'ont pas d'ISBN)
    \ifx\empty\@NDLISBN\else
    \newline ISBN \@NDLISBN
    \fi
  }
  \vspace{6mm}\par\nobreak\ignorespaces
}
{\par\vspace{\baselineskip}\hspace*{\fill}\textbf{\@NDLsign}}
%
% Environnement général
%
\newenvironment{NDL}
{%
  \newpage
  \refstepcounter{article}% Précaution pour remettre tous les
                          % compteurs de plan à zéro
  \Qdt@DefineThanks % Pour la note du sous-titre
  \twocolumn[%
    {% pour protéger les crochets de la commande \makebox
      % Point d'interrogation en blanc dans l'ellipse en pleine page
      % L'emplacement dépend de la parité de la page.
      \ifodd\c@page
      % cas impair : ellipse à droite
        \makebox[0pt][l]{%
          \hspace*{\linewidth}% positionnement sur la marge droite
          \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
          \smash{%
            \raisebox{-20mm}{%
              \includegraphics{ellipse}%
            }%
          }%
        }%
      \else
      % cas pair : ellipse à gauche
        \makebox[0pt][r]{%
          \smash{%
            \raisebox{-20mm}{%
              \includegraphics{ellipse}%
            }%
          }%
          \hspace*{0.5cm}% moins 1.5cm (2cm-1.5cm=0.5cm)
        }%
      \fi
      {%
        \Qdt@titlerubriccolor
        \Qdt@smalltitlerubricfont
        Notes de lecture
        \par
      }%
      \addcontentsline{toc}{article}{%
        \protect\Qdt@titletocarticlecolor
        \protect\Qdt@titletocarticlefont
        Notes de lecture%
      }%
      \vskip20mm\relax
      {%
        \Qdt@NDLsubtitlefont
        \'Editeurs, auteurs, envoyez-nous vos livres ; lecteurs
        souhaitant intervenir dans ces Notes de lecture,
        contactez-nous \thanks{\parbox[t]{.8\linewidth}{%
            \emph{Quadrature}, Roger Mansuy,
          Lyc\'ee Louis le Grand, casier 27, 123 rue Saint-Jacques,
          75005 Paris.\newline \protect\url{contact@quadrature.info}}}.%
%        La liste des ouvrages re\c cus se trouve en fin de rubrique.
      }%
      \par\vskip3cm\relax
    }%
  ]
  \Qdt@UseThanksBis
  % Pour les auteurs de toutes la rubrique
  \Qdt@TypesetNDLauthor
}
% Pose de l'étiquette de fin de rubrique.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page de la rubrique %%%
%%%    Le Coin des Problèmes    %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Nouveaux énoncés
%
\newenvironment{newproblem}[2]{%
  % #1 = numéro de l'énoncé
  % #2 = auteur de l'énoncé
  \par\addvspace{12pt plus6pt minus3pt}
  \noindent
  {%
    \Qdt@CDPtitlestatementcolor
    \Qdt@CDPtitlestatementfont
    Énoncé \no E.#1%
    \def\CDP@authornewproblem{#2}%
    \unless\ifx\empty\CDP@authornewproblem
    \Qdt@CDPauthornewstatementcolor
    \Qdt@CDPauthornewstatementfont
    ~-- #2
    \fi
    \par\nobreak
  }
  \vspace{6pt plus3pt minus2pt}
%  \Qdt@CDPnewstatementcolor
}
{}
%
% Anciens énoncés
%
\newenvironment{oldproblem}[3]{%
  % #1 = numéro de l'énoncé
  % #2 = numéro de l'ancienne revue
  % #3 = page de l'ancienne revue
  \par\addvspace{12pt plus6pt minus3pt}
  \noindent
  {%
    \Qdt@CDPtitlestatementcolor\Qdt@CDPtitlestatementfont
    Énoncé \no E.#1
    \hfill
    \Qdt@CDPoldreviewcolor
    \Qdt@CDPoldreviewfont
    (\emph{Quadrature} \no #2, page #3)
    \par\nobreak
  }
  \vspace{6pt plus3pt minus2pt}
  \Qdt@CDPnewstatementcolor
}
{}
%
% Gestion des auteurs multiples
%
\newcommand*\Qdt@TypesetCDPAuthor[1]{%
  \Qdt@nbAuthor \z@
  \expandafter\Qdt@@TypesetCDPAuthor#1\and\stop
  \let\next\Qdt@@@TypesetCDPAuthor
  \expandafter\next#1\and
}
\def\Qdt@@TypesetCDPAuthor#1\and#2\stop{%
  \advance\Qdt@nbAuthor \@ne
  \ifx\relax#2\relax
    \else
    \Qdt@@TypesetCDPAuthor#2\stop
  \fi
}
\def\Qdt@@@TypesetCDPAuthor#1\and{%
  \leavevmode\hbox{#1}\unskip
  \advance\Qdt@nbAuthor \m@ne
  \ifnum\Qdt@nbAuthor>\@ne
    ,
  \else\ifnum\Qdt@nbAuthor=\@ne
      ~et %
  \else
    \let\next\relax
  \fi\fi
  \next
}
%
% Gestion de l'en-tête des articles avec une syntaxe <clé>=<valeur>
% Les clés suivantes sont disponibles :
% - author -> liste des auteurs séparés par des \and (écrit sous le
%             sous-titre). Valeur par défaut = Pierre Bornsztein
% - abstract -> contenu du résumé (il vaut mieux placer ce résumé entre
%              accolades puisque les virgules seraient interdites,
%              ainsi que les sauts de paragraphe)
%
% - spaceafterabstract -> hauteur de l'espacement vertical après le
%                         résumé (1.5cm par défaut)
\define@key{CDP}{author}{%
  \gdef\CDP@author{#1}%
}
\define@key{CDP}{abstract}{\long\gdef\CDP@abstract{#1}}
\newlength{\QDT@spaceafterabstract}
\define@key{CDP}{spaceafterabstract}{\setlength{\QDT@spaceafterabstract}{#1}}
%
% Environnement général pour la rubrique
%
\newenvironment{CDP}[1][]
{%
  \newpage % Précaution pour le \refstepcounter qui suit
  % Numéro d'article en cours
  \refstepcounter{article}
  % remet tous les compteurs (footnote et thmslikes, etc. à zéro)
  \QDT@ResetCounter
  % Remise aux valeurs par défaut des clés avant leur lecture
  \def\CDP@author{Pierre Bornsztein}%
  \def\CDP@abstract{%
    Cette rubrique entend proposer des énoncés brefs et attractifs,
    dans le style des compétitions mathématiques, mais de difficulté
    plus ou moins grande, et sans contrainte de niveau. Il suffit
    qu'un problème vous ait semblé \og plaisant et délectable \fg{},
    vous ait fait chercher\dots{}
    \par\bigskip
    Envoyez vos nouveaux énoncés, avec les éléments de solution dont
    vous disposez, à~:
    \par\bigskip
    Pierre Bornsztein\\
    94, rue Jean Mermoz\\
    78600 Maison-Laffitte\\
    \url{pbquad@voila.fr}
    \par\bigskip
    Envoyez aussi les solutions non encore publiées\dots
  }%
  \setlength{\QDT@spaceafterabstract}{1.5cm}
  % Récupère toutes les informations (auteur(s) et résumé éventuel)
  \setkeys{CDP}{#1}%
  % Mise en forme de l'en-tête
  \twocolumn[%
    \begingroup
    \vspace*{3cm} % cf. quad 78 pour maquette de cette rubrique
      {\Qdt@CDPtitlefont\Qdt@titlerubriccolor
        \resizebox{\linewidth}{!}{Le Coin des problèmes} \par
      }%
      \addcontentsline{toc}{article}{%
        \protect\Qdt@titletocarticlecolor
        \protect\Qdt@titletocarticlefont
        Le Coin des problèmes%
      }%
      \unless\ifx\@author\empty
        \vskip 4mm
        {%
          \Qdt@authorfont\Qdt@authorcolor 
          {\small\textit{par}} \Qdt@TypesetCDPAuthor{\CDP@author}
          \par
        }%
      \fi
      \ifx\CDP@abstract\empty
        \@latex@warning@no@line{No abstract for "Coin des problemes"}%
      \else
        \vskip 8mm
        \setbox0=\hbox{%
          \kern6pt
          \minipage{\linewidth-1.6cm-12pt}
            \vspace*{6pt}
            \Qdt@CDPabstractfont
            \Qdt@abstractcolor
            \CDP@abstract
            \par\vspace*{6pt}
          \endminipage
          \kern6pt
        }%
        \begin{center}
          \begin{minipage}{\linewidth-1.6cm}
            \Qdt@rulecolor \hrule width 3cm height 1pt
            \hbox{\vrule width 1pt \kern2pt \box0}%
            \hrule height 1pt
          \end{minipage}
        \end{center}
      \fi
    \endgroup
    \par
    \vskip \QDT@spaceafterabstract
  ]
  % Dans cette rubrique, les sections ne sont pas numérotées
  \setcounter{secnumdepth}{-2}%
  % 
}
% Pose de l'étiquette de fin de rubrique.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Mise en page d'un article (général) %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Gestion des auteurs multiples
%
\newcount\Qdt@nbAuthor
\let\and\relax
\newcommand*\Qdt@TypesetArticleAuthor[1]{%
  \Qdt@nbAuthor \z@
  \expandafter\Qdt@@TypesetArticleAuthor#1\and\stop
  \let\next\Qdt@@@TypesetArticleAuthor
  \expandafter\next#1\and
}
\def\Qdt@@TypesetArticleAuthor#1\and#2\stop{%
  \advance\Qdt@nbAuthor \@ne
  \ifx\relax#2\relax
    \else
    \Qdt@@TypesetArticleAuthor#2\stop
  \fi
}
\def\Qdt@@@TypesetArticleAuthor#1\and{%
  \leavevmode\hbox{#1}\unskip
  \advance\Qdt@nbAuthor \m@ne
  \ifnum\Qdt@nbAuthor>\@ne
    ,
  \else\ifnum\Qdt@nbAuthor=\@ne
      ~et %
  \else
    \let\next\relax
  \fi\fi
  \next
}
%
% Commandes pour passer l'article entier en 10 points
% (\SmallerArticle) ou en 12 points (\BiggerArticle)
%
\newcommand\SmallerArticle{%
  \makeatletter
  \renewcommand\normalsize{%
    \@setfontsize\normalsize\@xpt\@xiipt
    \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
    \abovedisplayshortskip \z@ \@plus3\p@
    \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
    \belowdisplayskip \abovedisplayskip
    \let\@listi\@listI}%
  \normalsize
  \renewcommand\small{%
    \@setfontsize\small\@ixpt{11}%
    \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
    \abovedisplayshortskip \z@ \@plus2\p@
    \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
    \def\@listi{\leftmargin\leftmargini
                 \topsep 4\p@ \@plus2\p@ \@minus2\p@
                 \parsep 2\p@ \@plus\p@ \@minus\p@
                 \itemsep \parsep}%
     \belowdisplayskip \abovedisplayskip
   }%
   \renewcommand\footnotesize{%
     \@setfontsize\footnotesize\@viiipt{9.5}%
     \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
     \abovedisplayshortskip \z@ \@plus\p@
     \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
     \def\@listi{\leftmargin\leftmargini
                 \topsep 3\p@ \@plus\p@ \@minus\p@
                 \parsep 2\p@ \@plus\p@ \@minus\p@
                 \itemsep \parsep}%
     \belowdisplayskip \abovedisplayskip
   }%
   \renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}%
   \renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}%
   \renewcommand\large{\@setfontsize\large\@xiipt{14}}%
   \renewcommand\Large{\@setfontsize\Large\@xivpt{18}}%
   \renewcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}%
   \renewcommand\huge{\@setfontsize\huge\@xxpt{25}}%
   \renewcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}%
   \setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}%
   \setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}%
   \setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}%
  \makeatother
}
\newcommand\BiggerArticle{%
  \makeatletter
  \renewcommand\normalsize{%
    \@setfontsize\normalsize\@xiipt{14.5}%
    \abovedisplayskip 12\p@ \@plus3\p@ \@minus7\p@
    \abovedisplayshortskip \z@ \@plus3\p@
    \belowdisplayshortskip 6.5\p@ \@plus3.5\p@ \@minus3\p@
    \belowdisplayskip \abovedisplayskip
    \let\@listi\@listI}%
  \normalsize
  \renewcommand\small{%
    \@setfontsize\small\@xipt{13.6}%
    \abovedisplayskip 11\p@ \@plus3\p@ \@minus6\p@
    \abovedisplayshortskip \z@ \@plus3\p@
    \belowdisplayshortskip 6.5\p@ \@plus3.5\p@ \@minus3\p@
    \def\@listi{\leftmargin\leftmargini
                \topsep 9\p@ \@plus3\p@ \@minus5\p@
                \parsep 4.5\p@ \@plus2\p@ \@minus\p@
                \itemsep \parsep}%
    \belowdisplayskip \abovedisplayskip
  }%
  \renewcommand\footnotesize{%
    \@setfontsize\footnotesize\@xpt\@xiipt
    \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
    \abovedisplayshortskip \z@ \@plus3\p@
    \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
    \def\@listi{\leftmargin\leftmargini
                \topsep 6\p@ \@plus2\p@ \@minus2\p@
                \parsep 3\p@ \@plus2\p@ \@minus\p@
                \itemsep \parsep}%
    \belowdisplayskip \abovedisplayskip
  }%
  \renewcommand\scriptsize{\@setfontsize\scriptsize\@viiipt{9.5}}%
  \renewcommand\tiny{\@setfontsize\tiny\@vipt\@viipt}%
  \renewcommand\large{\@setfontsize\large\@xivpt{18}}%
  \renewcommand\Large{\@setfontsize\Large\@xviipt{22}}%
  \renewcommand\LARGE{\@setfontsize\LARGE\@xxpt{25}}%
  \renewcommand\huge{\@setfontsize\huge\@xxvpt{30}}%
  \let\Huge=\huge
  \setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}%
  \setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}%
  \setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}%
  \makeatother
}
%
% Gestion de l'en-tête des articles avec une syntaxe <clé>=<valeur>
% Les clés suivantes sont disponibles :
% - subarticle -> catégorie de l'article (affiché entre crochets
%   complètement en haut à droite
% - title -> titre de l'article (obligatoire)
% - subtitle -> sous-titre de l'article (écrit sous le titre)
% - author -> liste des auteurs séparés par des \and (écrit sous le
%             sous-titre)
% - abstract -> contenu du résumé (il vaut mieux placer ce résumé
%               entre accolades puisque les virgules seraient
%               interdites, ainsi que les sauts de paragraphe)
% - abstractmargin -> retrait gauche et droite pour composer le résumé
%                     (valeur par défaut = 1.5cm)
% - abstracttitle -> titre du résumé (valeur par défaut « Résumé »)
%                    si cette clé est vide, il n'y a rien de composé
%                    y compris pas d'espacement vertical.
%
% - spaceafterabstract -> hauteur de l'espacement vertical après le
%                         résumé (1.5cm par défaut)
\define@key{article}{subarticle}{\gdef\@subarticle{#1}}
\define@key{article}{title}{%
  \gdef\@title{#1}%
  \addcontentsline{toc}{article}{%
    \protect\Qdt@titletocarticlecolor
    \protect\Qdt@titletocarticlefont
    #1%
  }%
}
\define@key{article}{subtitle}{\gdef\@subtitle{#1}}
\define@key{article}{author}{%
  \gdef\@author{#1}%
  \ifx\relax#1\relax
  \else
    \addtocontents{toc}{\protect\l@author{#1}}%
  \fi
}
\define@key{article}{abstract}{\gdef\@abstract{#1}}
% abstract margin
\newdimen\@abstractmargin
\@abstractmargin=1.5cm % default value
%
\define@key{article}{abstractmargin}{\global\@abstractmargin=#1\relax}
\define@key{article}{abstracttitle}{\gdef\@abstracttitle{#1}}
\define@key{article}{spaceafterabstract}{\setlength{\QDT@spaceafterabstract}{#1}}
\define@key{article}{epigraphe}{\gdef\@epigraphe{#1}}
%
% Environnement article. L'essentiel du boulot est fait par
% \makearticletitle. En fait, on pourrait faire une commande mais je
% ne désespère pas de trouver une solution entièrement automatique
% pour gérer la dernière page (colonne équilibrée) et un environnement
% sera alors préférable.
%
\newenvironment{article}[1][]
{%
  \newpage % Précaution pour le \refstepcounter qui suit
  % Numéro d'article en cours
  \refstepcounter{article}
  % remet tous les compteurs (footnote et thmslikes, etc. à zéro)
  \QDT@ResetCounter
  % Récupère toutes les informations (titre, sous-titre, auteur(s),
  % résumé, type de sous-article). Par défaut le titre du résumé est
  % « Résumé ».
  \gdef\@abstracttitle{R\'esum\'e}%
  \gdef\@epigraphe{}%
  \setlength{\QDT@spaceafterabstract}{1.5cm}
  \setkeys{article}{#1}%
  % Mise en forme de la partie en simple colonne
  \makearticletitle
  % Dans les articles, les sections sous-sections
  % et sous-sous-sections sont numérotées
  \setcounter{secnumdepth}{3}%
}
% Pose de l'étiquette de fin d'article.
{%
  \protected@write\@auxout{}%
    {\string\newlabel{last\the\c@article}{{}{\thepage}}}%
  \ifQDT@experimental
    \QDT@AutomaticBalancedColumn
  \fi
  \pagebreak
}
%
% Partie introductive d'un article sur une colonne
%
\newcommand\makearticletitle{%
  \begingroup
    % Dans la partie introductive, il n'y a jamais de retrait
    % d'alinéa. Le groupe protège \parindent et \thanks
    \parindent \z@
    % Pose de la marque de première page
    \label{first\the\c@article}
    % Initialisation du mécanisme en deux temps de \thanks
    \Qdt@DefineThanks
    % Composition effective avant le passage en double colonne
    \twocolumn[\@makearticletitle]
  \endgroup
  % Remise des valeurs par défaut des différentes clés
  \gdef\@subarticle{}%
  \gdef\@author{}%
  \gdef\@title{\@latex@error{No title given}\@ehc}%
  \gdef\@subtitle{}%
  \gdef\@abstract{}%
  \gdef\@abstracttitle{}%
  \global\@abstractmargin=1.5cm
  \global\QDT@spaceafterabstract=1.5cm
  \gdef\@epigraphe{}%
  % Composition des corps de notes de bas de page.
  \Qdt@UseThanks
}
\def\@makearticletitle{%
  \null
  {%
    \minipage{\widthof{\Qdt@DOIfont Quadrature \no 00 (0000) 00-00}}
      \Qdt@DOIcolor
      \Qdt@DOIfont
      Quadrature \no \@numero{} (\@magazineyear)
      \pageref{first\the\c@article}-\pageref{last\the\c@article}\\
      \copyright{} Quadrature, \@magazineyear
    \endminipage
    \hfill
    \unless\ifx\@subarticle\@empty
      {\Qdt@subarticlebracketfont\Qdt@subarticlebracketcolor[}%
      {\Qdt@subarticlefont\Qdt@subarticlecolor\@subarticle}%
      {\Qdt@subarticlebracketfont\Qdt@subarticlebracketcolor]}%
    \fi
  }%
  \vskip 2cm%
  \begingroup
    \let \footnote \thanks
    {\Qdt@titlearticlefont\Qdt@titlearticlecolor \@title \par}%
    \unless\ifx\@subtitle\empty
      \vskip 4mm
      {\Qdt@subtitlearticlefont\Qdt@subtitlearticlecolor \@subtitle\par}%
    \fi
    \unless\ifx\@author\empty
      \vskip 4mm
      {%
        \Qdt@authorfont\Qdt@authorcolor 
        {\small\textit{par}} \Qdt@TypesetArticleAuthor{\@author}
        \par
      }%
    \fi
    % Les résumés utilisent des numéros de notes comme dans le
    % corps de l'article.
    \global\Qdt@hookfootnote\expandafter{%
      \the\Qdt@hookfootnote
      \def\dotFFN{.}%
      \setcounter{footnote}{0}%
      \renewcommand\thefootnote{\@arabic\c@footnote}%
    }%
    \ifx\@abstract\empty
      \@latex@warning@no@line{No abstract for article \@title}%
    \else
      \setcounter{footnote}{0}%
      \renewcommand\thefootnote{\@arabic\c@footnote}%
      \vskip 8mm
      \setbox0=\hbox{\kern6pt
        \minipage{\linewidth-2\@abstractmargin-12pt}
          \vspace*{6pt}
          \unless\ifx\@abstracttitle\empty
            {%
              \Qdt@titleabstractfont\Qdt@titleabstractcolor
              \@abstracttitle.
              \par\medskip
            }
          \fi
          \Qdt@abstractfont\Qdt@abstractcolor
          \@abstract
        \par\vspace*{6pt}
        \endminipage
        \kern6pt
      }%
      \begin{center}
        \begin{minipage}{\linewidth-2\@abstractmargin}
          \Qdt@rulecolor \hrule width 2.2cm height 1pt
          \hbox{\vrule width 1pt \kern2pt \box0}%
          \hrule height 1pt
        \end{minipage}
      \end{center}
    \fi
    % Composition d'une éventuelle épigraphe
    \unless\ifx\@epigraphe\empty
      \vskip 4mm
      \begin{flushright}
        \Qdt@epigraphefont\Qdt@epigraphecolor
        \@epigraphe
      \end{flushright}
    \fi
  \endgroup
  \par
  \vskip \QDT@spaceafterabstract
}
%
% Les commandes \title et \author sont  déjà définies par la classe de
% base (article).
% Pour l'instant, je laisse ces commandes qui permettent de déterminer
% les différents éléments d'un article ou d'une rubrique avant
% d'appeler l'environnement mais à terme, l'utilisation de l'argument
% optionnel de l'environnement deviendra obligatoire et le code
% ci-dessous disparaitra en partie (il restera \magazineyear,
% \magazinemonth et \numero) et la définition de base des commandes
% privées\@nom.
%
\newcommand*\magazineyear[1]{\gdef\@magazineyear{#1}}
\def\@magazineyear{\@latex@error{No \noexpand\magazineyear given}\@ehc}
\newcommand*\magazinemonth[1]{\gdef\@magazinemonth{#1}}
\def\@magazinemonth{\@latex@error{No \noexpand\magazinemonth given}\@ehc}
%
\newcommand*\subarticle[1]{\gdef\@subarticle{#1}}
\def\@subarticle{}
%
\newcommand*\subtitle[1]{\gdef\@subtitle{#1}}
\def\@subtitle{}
%
\renewcommand\abstract[1]{\long\gdef\@abstract{#1}}
\def\@abstract{}
%
\newcommand\abstracttitle[1]{\long\gdef\@abstracttile{#1}}
\def\@abstracttitle{}
%
\newcommand\numero[1]{\gdef\@numero{#1}}
\def\@numero{\@latex@error{No \noexpand\numero given}\@ehc}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Abréviations communes %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%
%%% Macros de plan %%%
%%%%%%%%%%%%%%%%%%%%%%
%
% Rien de rien dans la tdm qui ne soit autorisé explicitement avec le
% niveau -3
%
\setcounter{tocdepth}{-2}
%
% Point de suite de la tdm
% Cela donne envion 10 intervales sur 1,8 cm.
%
\renewcommand\@dotsep{2}
%
% Façon d'imprimer les titres d'articles dans la tdm
%
\newcommand\l@article{%
  \par\addvspace{.3em \@plus\p@ \@minus0.5em}
  \@dottedtocline{-3}{0pt}{0pt}%
}
%
% Façon d'imprimer les auteurs dans la tdm
%
\newcommand\l@author[1]{%
  \begingroup
    % Pas de note dans la TDM
    \def\thanks##1{}%
    \parindent \z@ \rightskip \@pnumwidth
    \parfillskip -\@pnumwidth
    \leavevmode
    \Qdt@titletocauthorcolor\Qdt@titletocauthorfont
    \raggedright
    Par \Qdt@TypesetArticleAuthor{#1}\par
  \endgroup
}
%
% Numérotation par défaut jusqu'à \subsubsection
%
\setcounter{secnumdepth}{3}
%
% Composition des macros de plan
%
\newcommand\TEQsection{\@startsection
  {section}% compteur (inutilisé)
  {8}%   gros numéro => pas de numérotation
  {0pt}% pas de retrait
  {18pt plus 12pt minus 6pt}% espace avant
  {6pt plus 4pt minus 2pt}%   espace après
  {%     mise en forme du titre
    \Qdt@TEQsectioncolor
    \Qdt@TEQsectionfont
  }%
}
\newcommand\Qdt@section@raggedright[1]{%
  \raggedright
  \setlength{\@tempdima}{\widthof{\csname the#1\endcsname\quad}}%
  \def\\{%
    \par\nobreak
    \noindent
    \hspace*{\@tempdima}%
    \ignorespaces
  }%
}
\newcommand\Qdt@section@centering[1]{%
  \centering
  \setlength{\@tempdima}{\widthof{\csname the#1\endcsname\quad}}%
  \def\\{%
    \par\nobreak
    \noindent
    \hspace*{\@tempdima}%
    \ignorespaces
  }%
}
\@addtoreset{section}{article}% Remise à zéro à chaque article ou
                              % rubrique
\renewcommand\section{\@startsection
  {section}%
  {1}%
  {\z@}%
  {-3.5ex \@plus -1ex \@minus -.2ex}%
  {2.3ex \@plus.2ex}%
  {%
    \Qdt@sectioncolor
    \Qdt@sectionfont
    \Qdt@section@raggedright{section}%
  }%
}
\renewcommand\subsection{\@startsection
  {subsection}%
  {2}%
  {\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {%
    \Qdt@subsectioncolor
    \Qdt@subsectionfont
    \Qdt@section@raggedright{subsection}%
  }%
}
\renewcommand\subsubsection{\@startsection
  {subsubsection}%
  {3}%
  {\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {%
    \Qdt@subsubsectioncolor
    \Qdt@subsubsectionfont
    \Qdt@section@raggedright{subsubsection}%
  }%
}
\renewcommand\paragraph{\@startsection
  {paragraph}%
  {4}%
  {\z@}%
  {3.25ex \@plus1ex \@minus.2ex}%
  {-1em}%
  {%
    \Qdt@paragraphcolor
    \Qdt@paragraphfont
    \Qdt@section@raggedright{paragraph}%
  }%
}
\renewcommand\subparagraph{\@startsection
  {subparagraph}%
  {5}%
  {\parindent}%
  {3.25ex \@plus1ex \@minus .2ex}%
  {-1em}%
  {%
    \Qdt@subparagraphcolor
    \Qdt@subparagraphfont
    \Qdt@section@raggedright{subparagraph}%
  }%
}
\renewcommand\thesection{\Roman{section}}
\renewcommand\thesubsection{\thesection.\arabic{subsection}}
\renewcommand\thesubsubsection{\thesubsection.\arabic{subsubsection}}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Symboles mathématiques %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% La numérotation des équations sont remises à zéro à chaque article
%
\@addtoreset{equation}{article}
%
% Theorem like
% compteur commun à tous les environnements
\newcounter{allthmlike}
% Une commande commune permet de déclarer les environnements pour
% l'environnement simple, l'environnement au pluriel et les deux sans
% numérotation (environnements étoilées)
%
\newcommand*\QDTdeclaretheorem[2]{%
  % #1 = nom de l'environnement de base
  % #2 = titre de l'environement (au singulier)
  % environnement au singulier
  \declaretheorem[name={\Qdt@titletheoremfont\Qdt@titletheoremcolor
    #2}, sibling=allthmlike]{#1}
  % environnement au pluriel 
  \declaretheorem[name={\Qdt@titletheoremfont\Qdt@titletheoremcolor
    #2s}, sibling=allthmlike]{#1s}
  % environnement au singulier non numéroté
  \declaretheorem[name={\Qdt@titletheoremfont\Qdt@titletheoremcolor
    #2}, numbered=no]{#1*}
  % environnement au pluriel non numéroté
  \declaretheorem[name={\Qdt@titletheoremfont\Qdt@titletheoremcolor
    #2s}, numbered=no]{#1s*}
}
\declaretheoremstyle[bodyfont=\upshape]{up}
\QDTdeclaretheorem{theo}{Th\'eor\`eme}
\QDTdeclaretheorem{propr}{Propri\'et\'e}
\QDTdeclaretheorem{prop}{Proposition}
\QDTdeclaretheorem{coro}{Corollaire}
\QDTdeclaretheorem{lem}{Lemme}
\QDTdeclaretheorem{ex}{Exemple}
\QDTdeclaretheorem{rem}{Remarque}
\QDTdeclaretheorem{defn}{D\'efinition}
\QDTdeclaretheorem{conj}{Conjecture}
\QDTdeclaretheorem{notation}{Notation}
\QDTdeclaretheorem{conv}{Convention}
\QDTdeclaretheorem{app}{Application}
\QDTdeclaretheorem{hyp}{Hypoyh\`ese}
\QDTdeclaretheorem{com}{Commentaire}
\QDTdeclaretheorem{resume}{R\'esum\'e}
% Style particulier
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Exercice, style=up]{exo}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Exercices, style=up]{exos}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Corrig\'e, sibling=exo, style=up]{corrige}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Corrig\'es, sibling=exo, style=up]{corriges}
% Pluriel embêtant !
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Simulation informatique]{simul}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Simulations informatiques]{simuls}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Simulation informatique, numbered=no]{simul*}
\declaretheorem[name=\Qdt@titletheoremfont\Qdt@titletheoremcolor
  Simulations informatiques, numbered=no]{simuls*}
%
% Composition des démonstrations
%
\declaretheoremstyle[
  title={\itshape D\'{e}monstration},
  numbered=no,
  bodyfont=\normalfont]{styleproof}
\declaretheorem[style=styleproof]{baseproof}
\renewenvironment{proof}
{\begin{baseproof}}
{%
  % En fin de démontration, passage à la ligne s'il reste moins de
  % 1 cm de libre
  \hspace*{1cm}\penalty0\hspace{-1cm}%
  % Affichage d'un carré en fin de ligne (équivalent de \qed)
  \null\hfill\textcolor{Qdt@qedcolor}{%
    \setlength{\fboxsep}{3pt}%
    \setlength{\fboxrule}{1pt}%
    \raisebox{3.5pt}{\fbox{\vrule width0pt height1pt}}%
  }%
  \end{baseproof}
}
%
% Symboles d'ensembles
%
\newcommand{\K}{\mathbb{K}}
\newcommand{\N}{\mathbb{N}}
\newcommand{\Z}{\mathbb{Z}}
\newcommand{\Q}{\mathbb{Q}}
\newcommand{\R}{\mathbb{R}}
\newcommand{\C}{\mathbb{C}}
%
% vecteur et comagnie
%
\renewcommand*\vec[1]{%
  \mathchoice
  {\overrightarrow{\displaystyle #1}}
  {\overrightarrow{\textstyle #1}}
  {\overrightarrow{\scriptstyle #1}}
  {\overrightarrow{\scriptscriptstyle #1}}
}
%
% Logique
%
\let\donc\Rightarrow
